SystemOrganization addCategory: #'MEG-Tests'!
SystemOrganization addCategory: 'MEG-Tests-Factories'!
SystemOrganization addCategory: 'MEG-Tests-Factories-Tests'!
SystemOrganization addCategory: 'MEG-Tests-Integration-Interaction'!
SystemOrganization addCategory: 'MEG-Tests-Integration-Movie'!
SystemOrganization addCategory: 'MEG-Tests-Unit'!

TestCase subclass: #EruCreatesTheWorld
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Movie'!

!EruCreatesTheWorld methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:48'!
test_01_WorldCreation

	| world gandalf rivendell elrond  |
	world := MEGWorld new.
	rivendell := MEGSiteFactory new newSiteNamed: 'Rivendell'.
	gandalf := MEGCharacter named: 'Gandalf' homeSiteType: 'Haven'.
	elrond := MEGCharacter named: 'Elrond' homeSiteNamed: 'Rivendell'.
	
	world addSite: rivendell.
	world addCharacter: gandalf.
	world addCharacter: elrond.
	
! !

!EruCreatesTheWorld methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:53'!
test_02_SitesForCharactersShouldAlreadyBeInTheWorld

	| world gandalf rivendell elrond |
	world := MEGWorld new.
	rivendell := MEGSiteFactory new newSiteNamed: 'Rivendell'.
	gandalf := MEGCharacter named: 'Gandalf' homeSiteType: 'Haven'.
	elrond := MEGCharacter named: 'Elrond' homeSiteNamed: 'Rivendell'.
	
	self should: [world addCharacter: elrond] raise: NotFound.
	self should: [world addCharacter: gandalf] raise: NotFound.
	world addSite: rivendell.
	world addCharacter: elrond.
	world addCharacter: gandalf.
	
! !

TestCase subclass: #HomeSiteCriteriaTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!HomeSiteCriteriaTest commentStamp: '<historical>' prior: 0!
A HomeSiteCriteriaTest is a test class for testing the behavior of HomeSiteCriteria!

!HomeSiteCriteriaTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:26'!
test_01_CreationOfNamedCriteria

	| criteria |
	criteria := HomeSiteCriteria named: 'Rivendel'.
! !

!HomeSiteCriteriaTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:26'!
test_02_CreationOfTypeCriteria

	| criteria |
	criteria := HomeSiteCriteria type: 'Haven'.
! !

TestCase subclass: #MEGAgentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGAgentTest commentStamp: '<historical>' prior: 0!
A MEGAgentTest is a test class for testing the behavior of MEGAgent!

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:14'!
test_01_Defaults

	| agent |
	agent := MEGAgent new.
	self assert: agent name isNil.
	self assert: agent currentGeneralInfluence = 20.
	self assert: agent followers isEmpty.! !

!MEGAgentTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:16'!
test_02_Creation
	| agent |
	agent := MEGAgent named: 'Player 1'.
	self assert: agent name = 'Player 1'.
	self assert: agent currentGeneralInfluence = 20.
	self assert: agent followers isEmpty.! !

TestCase subclass: #MEGCharacterFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories-Tests'!

!MEGCharacterFactoryTest commentStamp: '<historical>' prior: 0!
A MEGCharacterFactoryTest is a test class for testing the behavior of MEGCharacterFactory!

!MEGCharacterFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:20'!
test_01_NewCharacters

	| chars |
	chars := MEGCharacterFactory new newCharacters.
	self assert: chars notEmpty.! !

!MEGCharacterFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:58'!
test_02_NewCharacterNamed

	| character |
	character := MEGCharacterFactory new newCharacterNamed: 'Wacho'.
	self assert: character notNil.
	! !

TestCase subclass: #MEGCharacterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGCharacterTest commentStamp: '<historical>' prior: 0!
A MEGCharacterTest is a test class for testing the behavior of MEGCharacter!

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:45'!
test_01_Defaults

	| character |
	character := MEGCharacter new.
	self assert: character name isNil.
	self assert: character homeSiteCriteria isNil.
	self assert: character companies isEmpty.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:35'!
test_02_CreationWithHomeSiteNamed
	| character |
	character := MEGCharacter named: 'Bilbo' homeSiteNamed: 'Bag Ends'.
	self assert: character name = 'Bilbo'.
	self assert: character homeSiteCriteria notNil.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 5/26/2016 23:45'!
test_03_CreationWithHomeSiteType
	| character |
	character := MEGCharacter named: 'Bilbo' homeSiteType: 'Haven'.
	self assert: character name = 'Bilbo'.
	self assert: character homeSiteCriteria notNil.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:10'!
test_04_SettingFollowedCharacter

	| character pipo |
	pipo := (MEGCharacter named: 'Pipo Pescador' homeSiteNamed: 'Lago Traful').
	character := MEGCharacter new.
	character characterFollowed: pipo.
	self assert: character characterFollowed = pipo.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:12'!
test_05_SettingCurrentSite

	| character site |
	site := MEGSite named: 'Lago Traful'.
	character := MEGCharacter new.
	character currentSite: site.
	self assert: character currentSite = site.! !

!MEGCharacterTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:34'!
test_06_Recruiting

	| colonel world rambo pueblito |
	world := MEGWorld new.
	colonel := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	colonel world: world.
	rambo := MEGCharacter named: 'Rambo' homeSiteNamed: 'Bowie, Arizona'.
	pueblito := MEGSite named: 'Hope, Washington'.
	colonel recruit: rambo at: pueblito.! !

TestCase subclass: #MEGRecruitCharacterActionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGRecruitCharacterActionTest commentStamp: '<historical>' prior: 0!
A MEGRecruitCharacterActionTest is a test class for testing the behavior of MEGRecruitCharacterAction!

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:05'!
test_01_Defaults

	| action |
	action := MEGRecruitCharacterAction new.
	self assert: action recruitee isNil.
	self assert: action recruiter isNil.
	self assert: action site isNil.
	self assert: action world isNil.! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:25'!
test_02_ConstructorMethod

	| world action |
	world := MEGWorld new.
	action := MEGRecruitCharacterAction world: world.
	self assert: action world = world.
	! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:22'!
test_03_SetRecrutee

	| action recrutee |
	recrutee := MEGCharacter named: 'Rambo' homeSiteNamed: 'Arizona'.
	action := MEGRecruitCharacterAction new.
	action recruitee: recrutee.
	self assert: action recruitee = recrutee.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:19'!
test_04_SetRecruiter

	| action recruiter |
	recruiter := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	action := MEGRecruitCharacterAction new.
	action recruiter: recruiter.
	self assert: action recruiter = recruiter.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:22'!
test_05_SetSite

	| action site |
	site := MEGSite named: 'Hope, Washington'.
	action := MEGRecruitCharacterAction new.
	action site: site.
	self assert: action site = site.
! !

!MEGRecruitCharacterActionTest methodsFor: 'public' stamp: 'SergioFedi 6/2/2016 14:28'!
test_06_Creation

	| world action recrutee recruiter site |
	world := MEGWorld new.
	action := MEGRecruitCharacterAction world: world.
	recrutee := MEGCharacter named: 'Rambo' homeSiteNamed: 'Arizona'.
	recruiter := MEGCharacter named: 'Sam Trautman' homeSiteNamed: 'USA'.
	site := MEGSite named: 'Hope, Washington'.
	
	action recruiter: recruiter.
	action recruitee: recrutee.
	action site: site.
	action perform.! !

TestCase subclass: #MEGSiteFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories-Tests'!

!MEGSiteFactoryTest commentStamp: '<historical>' prior: 0!
A MEGSiteFactoryTest is a test class for testing the behavior of MEGSiteFactory!

!MEGSiteFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:21'!
test_01_NewSites

	| sites |
	sites := MEGSiteFactory new newSites.
	self assert: sites notEmpty.
	! !

!MEGSiteFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:21'!
test_02_NewSiteNamed

	| site |
	site := MEGSiteFactory new newSiteNamed: 'Lorien'.
	self assert: site notNil.
	! !

TestCase subclass: #MEGSiteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGSiteTest commentStamp: '<historical>' prior: 0!
A MEGSiteTest is a test class for testing the behavior of MEGSite!

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:17'!
test_01_Defaults

	| site |
	site := MEGSite new.
	self assert: site name isNil.
	self assert: site type isNil.! !

!MEGSiteTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:17'!
test_02_Creation

	| site |
	site := MEGSite named: 'Dol-Amroth'.
	self assert: site name = 'Dol-Amroth'.
	self assert: site type isNil.! !

TestCase subclass: #MEGWorldFactoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories-Tests'!

!MEGWorldFactoryTest commentStamp: '<historical>' prior: 0!
A MEGWorldFactoryTest is a test class for testing the behavior of MEGWorldFactory!

!MEGWorldFactoryTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:39'!
test_01_newWorld

	self assert: MEGWorldFactory new newWorld notNil.! !

TestCase subclass: #MEGWorldTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Unit'!

!MEGWorldTest commentStamp: '<historical>' prior: 0!
A MEGWorldTest is a test class for testing the behavior of MEGWorld!

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:42'!
test_01_Creation

	| world |
	world := MEGWorld new.
	self assert: world locations isEmpty.
	self assert: world characters isEmpty.
	self assert: world agents isEmpty.! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:43'!
test_02_AddSite

	| world |
	world := MEGWorld new.
	world addSite: (MEGSite named: 'Lorien').
	self assert: world locations notEmpty.
	self assert: world locations size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:47'!
test_03_AddCharacter

	| world |
	world := MEGWorld new.
	world addSite: (MEGSiteFactory new newSiteNamed: 'Bag End').
	world addCharacter: (MEGCharacter named: 'Frodo' homeSiteNamed: 'Bag End').
	self assert: world characters notEmpty.
	self assert: world characters size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 17:23'!
test_04_RetrieveSite

	| world  |
	world := MEGWorld new.
	self should: [world siteNamed: 'Rivendell'] raise: NotFound.
	world addSite: (MEGSite named: 'Rivendell').
	self assert: (world siteNamed: 'Rivendell') notNil.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:50'!
test_05_RetrieveCharacter

	| world  |
	world := MEGWorld new.
	world addSite: (MEGSiteFactory new newSiteNamed: 'Edoras').
	self should: [world characterNamed: 'Eowyn'] raise: NotFound.
	world addCharacter: (MEGCharacter named: 'Eowyn' homeSiteNamed: 'Edoras').
	self assert: (world characterNamed: 'Eowyn') notNil.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:44'!
test_06_AddAgent

	| world |
	world := MEGWorld new.
	world addAgent: (MEGAgent named: 'Player 1').
	self assert: world agents notEmpty.
	self assert: world agents size = 1.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:45'!
test_07_AgentNamed

	| world |
	world := MEGWorld new.
	world addAgent: (MEGAgent named: 'Player 1').
	self assert: (world agentNamed: 'Player 1') notNil.
	self assert: (world agentNamed: 'Player 1') name = 'Player 1'.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:48'!
test_08_AddSites

	| world sites |
	world := MEGWorld new.
	sites := OrderedCollection
		with: (MEGSiteFactory new newSiteNamed: 'Bag End')
		with: (MEGSiteFactory new newSiteNamed: 'Lorien')
		with: (MEGSiteFactory new newSiteNamed: 'Lossadan Camp')
		with: (MEGSiteFactory new newSiteNamed: 'Moria').
	world addSites: sites.
	self assert: world locations notEmpty.
	self assert: world locations size = 4.
! !

!MEGWorldTest methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:59'!
test_09_AddCharacters

	| world characters |
	world := MEGWorld new.
	world addSite: (MEGSiteFactory new newSiteNamed: 'Bag End').
	characters := OrderedCollection
		with: (MEGCharacterFactory new newCharacterNamed: 'Bilbo')
		with: (MEGCharacterFactory new newCharacterNamed: 'Frodo')
		with: (MEGCharacterFactory new newCharacterNamed: 'Merry')
		with: (MEGCharacterFactory new newCharacterNamed: 'Pippin').
	world addCharacters: characters.
	self assert: world characters notEmpty.
	self assert: world characters size = 4.
! !

TestCase subclass: #TheCompanyFormsAtRivendel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Integration-Interaction'!

!TheCompanyFormsAtRivendel methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 11:52'!
newWorld

	| world |
	world := MEGWorldFactory new newWorld.	
	^world.! !

!TheCompanyFormsAtRivendel methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 11:29'!
newWorldWithCharacterPlayed: aString at: aString2 for: aString3

	| world |
	world := self newWorld.
	(world agentNamed: aString3) recruit: (world characterNamed: aString) at: (world siteNamed: aString2).
	^world.! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 17:22'!
test_01_WizardRecruitsGandalf

	| world rivendel gandalf wizard |
	world := self newWorld.
	rivendel := world siteNamed: 'Rivendell'.
	gandalf := world characterNamed: 'Gandalf'.
	wizard := world agentNamed: 'Jugador 1'.
	
	self assert: gandalf characterFollowed isNil.
	self assert: gandalf currentSite isNil.
	self deny: (wizard followers includes: gandalf).
	self deny: (rivendel occupants includes: gandalf).
	self assert: wizard currentGeneralInfluence = 20.
	wizard recruit: gandalf at: rivendel.
	self assert: (gandalf characterFollowed) = wizard.
	self assert: (gandalf currentSite) = rivendel.
	self assert: (wizard followers includes: gandalf).
	self assert: (rivendel occupants includes: gandalf).
	self assert: wizard currentGeneralInfluence = 20.! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 17:23'!
test_02_WizardRecruitsElrondIntoGeneralInfluence

	| world rivendel elrond wizard |
	world := self newWorld.
	rivendel := world siteNamed: 'Rivendell'.
	elrond := world characterNamed: 'Elrond'.
	wizard := world agentNamed: 'Jugador 1'.
	
	self assert: elrond characterFollowed isNil.
	self assert: elrond currentSite isNil.
	self deny: (wizard followers includes: elrond).
	self deny: (rivendel occupants includes: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	wizard recruit: elrond at: rivendel.
	self assert: (elrond agentFollowed) = wizard.
	self assert: (elrond currentSite) = rivendel.
	self assert: (wizard followers includes: elrond).
	self assert: (rivendel occupants includes: elrond).
	self assert: wizard currentGeneralInfluence = 10.! !

!TheCompanyFormsAtRivendel methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:37'!
test_03_WizardRecruitsElrondIntoGandalfsInfluence

	| world rivendel gandalf elrond wizard |
	world := self newWorldWithCharacterPlayed: 'Gandalf' at: 'Rivendell' for: 'Jugador 1'.
	rivendel := world siteNamed: 'Rivendell'.
	gandalf := world characterNamed: 'Gandalf'.
	elrond := world characterNamed: 'Elrond'.
	wizard := world wizardNamed: 'Jugador 1'.
	
	self assert: elrond characterFollowed isNil.
	self assert: elrond currentSite isNil.
	self deny: (wizard followers includes: elrond).
	self deny: (rivendel occupants includes: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	self assert: gandalf currentDirectIfnluence = 10.
	wizard recruit: elrond at: rivendel under: gandalf.
	self assert: (elrond characterFollowed) = gandalf.
	self assert: (elrond agentFollowed) = wizard.
	self assert: (elrond currentSite) = rivendel.
	self assert: (gandalf followers includes: elrond).
	self assert: (rivendel occupants includes: elrond).
	self assert: wizard currentGeneralInfluence = 20.
	self assert: gandalf currentDirectInfluence = 0.! !

Object subclass: #MEGElementFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

MEGElementFactory subclass: #MEGCharacterFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

!MEGCharacterFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 22:10'!
characterFromLine: line
	| character fields homeSite |
	fields := line substrings: #($,).
	character := MEGCharacter new.
	character name: fields first.
	homeSite := self homeSiteFrom: fields sixth.
	character homeSiteCriteria: homeSite.
	^character.! !

!MEGCharacterFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 22:04'!
charactersFromString: aString

	^aString lines collect: [ :line | self characterFromLine: line ].! !

!MEGCharacterFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 22:32'!
homeSiteFrom: aString

	(aString beginsWith: 'Any ') 
		ifTrue:  [ | type |
			type := aString allButFirst: 4.
			(type = 'Haven')
				ifTrue: [ ^HomeSiteCriteria type: type ]
				ifFalse: [ self halt ]
		]
		ifFalse: [ ^HomeSiteCriteria named: aString ].
	! !

!MEGCharacterFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 23:58'!
newCharacterNamed: aString

	^self newCharacters detect: [:each | each name = aString].! !

!MEGCharacterFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:03'!
newCharacters

	^self charactersFromString: self spoilerString.! !

!MEGCharacterFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 22:34'!
spoilerString

	^'Adrazar,Character,F1,Dunadan,Scout/Diplomat,Dol Amroth,1,3,1,3,6,0,David Dettrick,2,|Unique.  +1 direct influence against all factions.|
Alatar,Character,F2,Wizard,Warrior/Scout/Ranger/Sage,Edhellond,0,0,10,6,9,0,Angus McBride,10,|Unique. During the movement/hazard phase, the number of cards that opponent draws based on Alatar''s company''s movement is reduced by one.  If in a Haven when a hazard creature is played on another company, he may join tha company and face one of the hazard creature''s strikes; he must tap and make a corruption check immediately following the attack.|
Anborn,Character,U,Dunadan,Scout/Ranger,Pelargir,0,2,0,2,8,0,David Dettrick,10,|Unique.  +2 direct influence against the Men of Lebennin faction.|
Annalena,Character,F2,Elf,Scout/Sage,Edhellond,1,3,0,3,8,0,Angus McBride,9,|Unique.|
Aragorn II,Character,F1,Dunadan,Warrior/Scout/Ranger,Bree,3,9,3,6,9,0,Angus McBride,9,|Unique.  +2 direct influence against the Rangers of the North faction. -3 marshalling points if eliminated.|
Arinmir,Character,U,Elf,Sage/Diplomat,Edhellond,1,4,2,2,7,0,Angus McBride,9,|Unique.  +2 direct influence against the Variags faction.|
Arwen,Character,R,Elf,Scout/Sage,Rivendell,1,3,0,2,8,0,Angus McBride,9,|Unique.  +7 direct influence only usable against Aragorn II.|
Balin,Character,U,Dwarf,Warrior/Sage,Blue Mountain Dwarf-hold,2,5,2,4,7,0,Angelo Montanini,8,|Unique.  +2 prowess against Orcs.  +1 direct influence against Dwarves and Dwarf factions.|
Bard Bowman,Character,F2,Man,Warrior/Scout,Lake-town,0,2,0,3,6,0,Angelo Montanini,8,|Unique.  +2 direct influence against the Men of Northern Rhovanion faction.|
Barliman Butterbur,Character,U,Man,Warrior,Bree,0,1,0,2,6,0,April Lee,8,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Beorn,Character,F1,Man,Warrior/Ranger,Beorn''s House,2,7,2,7,9,0,Stefano Baldo,8,|Unique.  +2 direct influence against the Beornings faction.|
Beregond,Character,F1,Dunadan,Warrior,Minas Tirith,0,2,0,4,8,-1,Edward Beard, Jr.,8,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Beretar,Character,U,Dunadan,Warrior/Ranger,Bree,2,5,1,5,8,0,Angelo Montanini,7,|Unique.  +2 direct influence against the Rangers of the North faction.|
Bergil,Character,U,Dunadan,Scout,Minas Tirith,0,2,0,1,9,0,Stefano Baldo,7,|Unique.|
Bifur,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,2,0,4,7,0,Angelo Montanini,7,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Bilbo,Character,R,Hobbit,Scout/Sage,Bag End,2,5,1,1,9,0,Angus McBride,7,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +4.  -2 marshalling points if eliminated.|
Bofur,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,2,0,4,7,0,Angelo Montanini,7,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Bombur,Character,U,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,1,0,3,6,-1,Angelo Montanini,7,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Boromir II,Character,F2,Dunadan,Warrior,Minas Tirith,1,4,1,6,7,-1,Angelo Montanini,6,|Unique.  +2 direct influence against the Men of Anorien faction. -1 to all of his corruption checks.|
Celeborn,Character,F1,Elf,Warrior/Sage,Lorien,2,6,1,6,9,0,Angus McBride,6,|Unique.  +5 direct influence that is only usable against Galadriel.|
Cirdan,Character,R,Elf,Warrior/Sage/Diplomat,Grey Havens,3,8,4,6,8,0,Quinton Hoover,6,|Unique.  When Cirdan is at Grey Havens, his controlling player may keep one more card than normal in his hand.  May tap to cancel one attack keyed to a Coastal Sea region.  +2 direct influence against the Elves of Lindon faction.  -3 marshalling points if eliminated.|
Dain II,Character,R,Dwarf,Warrior/Diplomat,Iron Hill Dwarf-hold,2,7,3,5,8,0,Angus McBride,6,|Unique.  +2 direct influence against Iron Hill Dwarves, +2 prowess against Orcs. +1 direct influence against Men and Man factions.|
Damrod,Character,U,Dunadan,Scout/Ranger,Vale of Erech,0,2,0,2,7,0,Mark Poole,6,|Unique.  +2 direct influence against the Men of Lamedon faction.|
Denethor II,Character,R,Dunadan,Warrior/Sage,Minas Tirith,1,4,2,3,6,0,Angus McBride,5,|Unique.  +2 direct influence against the Tower Guard of Minas Tirith faction.|
Dori,Character,U,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,1,0,3,6,-1,Angelo Montanini,5,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks agains factions.|
Dwalin,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,1,0,2,7,-1,Angelo Montanini,5,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Elladan,Character,F1,Elf,Warrior/Ranger,Rivendell,1,4,0,5,8,0,April Lee,5,|Unique.  +1 prowess against Orcs.|
Elrohir,Character,F1,Elf,Warrior/Ranger,Rivendell,1,4,0,5,8,0,April Lee,4,|Unique.  +1 prowess against Orcs.|
Elrond,Character,R,Elf,Warrior/Sage/Diplomat,Rivendell,3,10,4,7,9,0,Kevin Ward,4,|Unique.  When Elrond is at Rivendell, his controlling player may keep one more card than normal in his hand. -3 marshalling points if eliminated.|
Eomer,Character,U,Man,Warrior/Ranger,Edoras,1,3,0,3,8,0,Angelo Montanini,3,|Unique.  +2 direct influence against the Riders of Rohan faction.|
Eowyn,Character,U,Man,Warrior/Scout,Edoras,0,2,0,2,7,0,Angelo Montanini,3,|Unique.  Against Nazgul, +6 to her prowess, and his body is halved (round up).|
Erkenbrand,Character,F1,Man,Warrior,Edoras,1,4,2,5,6,0,Angus McBride,4,|Unique.  +2 direct influence against the Riders of Rohan faction.|
Faramir,Character,F1,Dunadan,Warrior/Ranger,Henneth Annun,2,5,1,5,8,0,Angelo Montanini,2,|Unique.  +2 direct influence against the Rangers of Ithilien faction.|
Fili,Character,U,Dwarf,Warrior/Scout,Blue Mountain Dwarf-hold,0,2,0,2,8,0,Angelo Montanini,12,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Forlong,Character,CB,Dunadan,Warrior,Minas Tirith,0,1,0,3,7,-1,Quinton Hoover,11,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Frodo,Character,R,Hobbit,Scout/Diplomat,Bag End,2,5,1,1,9,4,Angus McBride,11,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +4.  -2 marshalling points if eliminated.|
Galadriel,Character,R,Elf,Scout/Sage/Diplomat,Lorien,3,9,4,3,10,0,Angus McBride,10,|Unique.  When Galadriel is at Lorien, her controlling player may keep one more card than normal in his hand.  -3 marshalling points if eliminated.|
Galva,Character,R,Man,Scout/Sage/Diplomat,Shrel-Kain,1,4,1,0,9,0,Quinton Hoover,10,|Unique.  +2 direct influence against the Men of Dorwinion faction.  Against Nazgul, +6 to her prowess, and his body is halved (round up).|
Gamling the Old,Character,U,Man,Warrior,Edoras,0,2,1,3,7,0,Angus McBride,10,|Unique.|
Gandalf,Character,F2,Wizard,Warrior/Scout/Sage/Diplomat,Any Haven,0,0,10,6,9,1,Olivier Frot,9,|Unique.  All of his corruption checks are modified by +1.  Can tap to "test" a gold ring.|
Ghan-buri-Ghan,Character,U,Man,Scout/Ranger,Druadan Forest,2,5,2,2,9,0,April Lee,9,|Unique.  +2 direct influence against Wose factions.|
Gildor Inglorion,Character,F1,Elf,Warrior/Ranger,Rivendell,1,4,0,5,7,0,Lori Deitrick,9,|Unique.  +2 prowess against Orcs.|
Gimli,Character,F1,Dwarf,Warrior/Diplomat,Iron Hill Dwarf-hold,2,6,2,5,8,0,Lori Deitrick,9,|Unique.  +2 direct influence against Iron Hill Dwarves.  +2 prowess against Orcs.  +1 direct influence against Elves and Elf factions.|
Gloin,Character,U,Dwarf,Warrior/Diplomat,Blue Mountain Dwarf-hold,2,5,2,5,7,0,Angelo Montanini,8,|Unique.  +2 direct influence against Blue Mountain Dwarves. +1 prowess against Orcs.  +1 direct influence against Dwarves and Dwarf factions.|
Glorfindel II,Character,F1,Elf,Warrior/Sage,Rivendell,3,8,2,8,9,0,Randy Gallegos,8,|Unique.  +1 direct influence against Elves.|
Halbarad,Character,U,Dunadan,Sage/Diplomat,Cameth Brin,0,1,1,0,5,0,Quinton Hoover,8,|Unique.  +2 direct influence against the Hillmen faction.|
Haldalam,Character,R,Dunadan,Warrior/Diplomat,Shrel-Kain,2,5,1,4,9,0,David Deitrick,8,|Unique.  +4 direct influence against the Easterlings faction.|
Haldir,Character,U,Elf,Warrior,Lorien,1,3,0,4,8,0,Lori Deitrick,8,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Hama,Character,CB,Man,Warrior,Edoras,0,2,0,4,8,-1,Lori Deitrick,7,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Imrahil,Character,U,Dunadan,Warrior/Diplomat,Dol Amroth,2,6,2,5,8,0,Donato Giancola,7,|Unique.  +2 direct influence against the Knights of Dol Amroth faction.|
Kili,Character,F2,Dwarf,Warrior/Scout,Blue Mountain Dwarf-hold,1,3,0,3,8,-1,Angelo Montanini,7,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Legolas,Character,U,Elf,Warrior/Diplomat,Thranduil''s Halls,2,6,2,5,8,0,Quinton Hoover,7,|Unique.  +2 direct influence against the Wood-elves faction.|
Mablung,Character,U,Dunadan,Warrior/Scout,Lond Galen,0,1,0,1,6,0,Margaret Organ-Keene,7,|Unique.  +2 direct influence against the Men of Anfalas faction.|
Merry,Character,U,Hobbit,Scout,Bag End,1,4,1,1,9,2,Angelo Montanini,7,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +2.|
Nori,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,2,0,4,7,0,Angelo Montanini,6,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Oin,Character,U,Dwarf,Warrior/Ranger,Blue Mountain Dwarf-hold,1,3,0,3,8,-1,Angelo Montanini,6,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.|
Ori,Character,CB,Dwarf,Warrior,Blue Mountain Dwarf-hold,0,1,0,2,7,0,Angelo Montanini,6,|Unique.  +1 prowess against Orcs.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Orophin,Character,CB,Elf,Warrior/Ranger,Lorien,0,2,0,2,7,0,Lori Deitrick,6,|Unique.  -1 to all of his corruption checks.  -1 to influence checks against factions.|
Pallando,Character,F2,Wizard,Warrior/Ranger/Sage/Diplomat,Grey Havens,0,0,10,6,9,0,Angus McBride,6,|Unique.  His controlling player may keep one more card than normal in his hand.  Opponent must discard his cards face-up.|
Peath,Character,F1,Man,Ranger/Diplomat,Dunnish Clan-hold,1,4,1,4,7,0,Stefano Baldo,5,|Unique.  +4 direct influence against the Dunlending faction. Against Nazgul, +5 to her prowess, his body is halved (round up).|
Pippin,Character,U,Hobbit,Scout,Bag End,1,4,1,1,9,0,Angelo Montanini,5,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +2.|
Radagast,Character,F2,Wizard,Warrior/Scout/Ranger/Diplomat,Rhosgobel,0,0,10,6,9,1,Angelo Montanini,5,|Unique.  If his company moves to a new site during the movement/hazard phase, he may draw 1 additional card for each Wilderness [w] region in his company''s site path.  +1 to all corruption checks.|
Robin Smallburrow,Character,F2,Hobbit,Scout,Bag End,1,3,0,1,9,0,Angelo Montanini,5,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +2.|
Sam Gamgee,Character,U,Hobbit,Scout/Ranger,Bag End,1,4,0,1,9,3,Angelo Montanini,4,|Unique.  Unless he is one of the starting characters, he may only be brought into play at his home site.  All of his corruption checks are modified by +3.|
Saruman,Character,F2,Wizard,Scout/Ranger/Sage/Diplomat,Isengard,0,0,10,6,9,0,Angus McBride,4,|Unique.  May tap to use a Palantir.  At the beginning of each of his end-of-turn phases, he may tap to take one "spell" card from his discard pile and return it to his hand.|
Theoden,Character,F1,Man,Warrior/Diplomat,Edoras,2,6,3,5,6,0,Angus McBride,4,|Unique.  +2 direct influence against the Riders of Rohan faction.|
Thorin II,Character,R,Dwarf,Warrior/Scout/Diplomat,Blue Mountain Dwarf-hold,3,8,2,5,8,0,Angelo Montanini,3,|Unique.  +2 direct influence against Blue Mountain Dwarves. +3 prowess against Orcs.  +2 direct influence against Dwarves and Dwarf factions.|
Thranduil,Character,F1,Elf,Warrior/Ranger/Sage,Thranduil''s Halls,3,9,3,7,8,0,Rob Alexander,3,|Unique.  +2 direct influence against the Wood-elves faction.|
Voteli,Character,CB,Man,Ranger/Sage,Lossadan Camp,1,3,1,3,6,0,Stefano Baldo,2,|Unique.  +2 direct influence against the Lossoth faction. Against Nazgul, +5 to her prowess, and his body is halved (round up).|
Vygavril,Character,R,Man,Diplomat/Sage,Southron Oasis,1,3,1,2,7,0,Jo Hartwig,7,|Unique.  +2 direct influence against the Southron faction. Against Nazgul, +6 to prowess, and his body is halved (round up).|
Wacho,Character,U,Man,Scout/Sage,Woodmen-town,0,2,0,1,8,0,Stefano Baldo,7,|Unique.  +2 direct influence against the Woodmen faction.|'.! !

!MEGElementFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 16:40'!
spoilerString

	^self subclassResponsibility.! !

MEGElementFactory subclass: #MEGSiteFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

!MEGSiteFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 22:47'!
newSiteNamed: aString

	^self newSites detect: [ :each | each name = aString ].! !

!MEGSiteFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 20:32'!
newSites
	^ self sitesFromString: self spoilerString! !

!MEGSiteFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 20:38'!
siteFromLine: aString
	| fields site |
	fields := aString substrings: #($,).
	site := MEGSite new.
	site name: fields first.
	site type: (self siteTypeFor: fields fifth).
	^site.! !

!MEGSiteFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 20:40'!
siteTypeFor: code

	| result |
	(code = 'H') ifTrue: [ result := 'Haven' ].
	^result.! !

!MEGSiteFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 21:20'!
sitesFromString: aString

	^aString lines collect: [ :line | self siteFromLine: line ].! !

!MEGSiteFactory methodsFor: 'private' stamp: 'SergioFedi 6/6/2016 21:22'!
spoilerString

	^'Amon Hen,Site,CA,Rohan,R,wb,Lorien,,,1,1,info/min,Undead,1,6,,0,0,|Each character wounded must make a corruption check.|,David Martin
Bag End,Site,F2,Shire,F,wwf,Rivendell,,,2,2,,,0,0,,0,0,||,Randy Asplund-Faith
Bandit Lair,Site,F3,Brown Lands,R,ws,Lorien,,,1,2,min/ring,Men,3,6,,0,0,||,Darryl Elliott
Barad-dur,Site,R,Gorgoroth,D,wbfwsd,Lorien,,,3,6,min/maj/gr,Orcs,4,7,Trolls,3,9,|Any company moving to Barad-Dur has its hazard limit modified by +2.|,Kevin Ward
Barrow-downs,Site,F1,Cardolan,R,ww,Rivendell,,,1,2,min/maj,Undead,1,8,,0,0,|Each character wounded must make a corruption check.|,Angus McBride
Beorn''s House,Site,F1,Anduin Vales,F,wb,Lorien,,,1,1,,,0,0,,0,0,||,Eric David Anderson
Blue Mountain Dwarf-hold,Site,CB,Numeriador,F,fw,Grey Havens,,,1,1,,,0,0,,0,0,||,Rob Alexander
Bree,Site,F1,Arthedain,B,ww,Rivendell,,,1,1,,,0,0,,0,0,||,Randy Gallegos
Cameth Brin,Site,CB,Rhudaur,B,w,Rivendell,,,1,1,,,0,0,,0,0,||,David Martin
Carn Dum,Site,R,Angmar,D,ws,Rivendell,,,2,3,min/maj/gr,Orcs,4,7,,0,0,||,J. Wallace Jones
Caves of Ulund,Site,U,Withered Heath,R,wbsw,Lorien,,,3,3,min/maj/gr/ring,Dragon,1,13,,0,0,||,Randy Asplund-Faith
Cirith Ungol,Site,R,Imlad Morgul,D,wbfws,Lorien,,,3,4,min/maj/gr,Orcs,4,7,,0,0,||,Mark Poole
Dancing Spire,Site,U,Withered Heath,R,wbsw,Lorien,,,3,3,min/maj/gr/ring,Dragon,2,11,,0,0,||,Pat Morrissey
Dead Marshes,Site,U,Dagorlad,S,wss,Lorien,,,2,3,min/maj/gr,Undead,2,8,,0,0,|Each character wounded must make a corruption check.|,Pat Morrissey
Dimrill Dale,Site,U,Redhorn Gate,R,ww,Lorien,,,1,1,info,Orcs,1,6,,0,0,||,Eric David Anderson
Dol Amroth,Site,CB,Belfalas,F,wf,Edhellond,,,1,1,,,0,0,,0,0,||,Mark Poole
Dol Guldur,Site,R,Southern Mirkwood,D,wbd,Lorien,,,2,4,min/maj/gr,Orcs,3,7,Trolls,2,8,||,Christina Wald
Druadan Forest,Site,CB,Anorien,B,wbf,Lorien,,,2,2,,,0,0,,0,0,||,Edward Beard, Jr.
Dunharrow,Site,R,Rohan,B,wb,Lorien,,,1,1,,,0,0,,0,0,||,N. Taylor Blanchard
Dunnish Clan-hold,Site,F1,Dunland,B,www,Rivendell,,,2,2,,,0,0,,0,0,||,Storn Cook
Eagles'' Eyrie,Site,CB,Anduin Vales,F,wb,Lorien,,,1,1,,,0,0,,0,0,||,Rob Alexander
Easterling Camp,Site,R,Horse Plains,B,wsss,Lorien,,,4,4,,,0,0,,0,0,||,Storn Cook
Edhellond,Site,CB,Anfalas,H,fccccw,Grey Havens,wbffbw,Lorien,2,2,,,0,0,,0,0,||,Christina Wald
Edoras,Site,F1,Rohan,F,wb,Lorien,,,1,1,,,0,0,,0,0,||,Margaret Organ-Keane
Ettenmoors,Site,CA,Rhudaur,R,w,Rivendell,,,1,1,min,Troll,1,9,,0,0,||,Rob Alexander
Gladden Fields,Site,CA,Anduin Vales,R,wb,Lorien,,,1,1,ring,Undead,1,8,,0,0,|Each character wounded must make a corruption check.|,Quinton Hoover
Glittering Caves,Site,U,Gap of Isen,R,wbb,Lorien,,,2,2,min/maj,Pukel-man,1,9,,0,0,||,David Martin
Goblin-gate,Site,F2,High Pass,S,ww,Rivendell,,,1,2,min/ring,Orcs,3,6,,0,0,||,Randy Gallegos
Grey Havens,Site,CB,Lindon,H,wwf,Rivendell,wccccf,Edhellond,2,2,,,0,0,,0,0,||,Mark Poole
Henneth Annun,Site,F1,Ithilien,B,wbfw,,,,2,2,,,0,0,,0,0,||,Rob Alexander
Himring,Site,U,Elven Shores,R,fc,Grey Havens,,,1,1,min/maj,Undead,1,8,,0,0,|Each character wounded must make a corruption check.|,J. Wallace Jones
Irerock,Site,U,Withered Heath,R,wbsw,Lorien,,,3,3,min/maj/gr/ring,Dragon,1,14,,0,0,||,Pat Morrissey
Iron Hill Dwarf-hold,Site,F1,Iron Hills,F,wbbww,Lorien,,,3,3,,,0,0,,0,0,||,Ron Rousselle II
Isengard,Site,F2,Gap of Isen,R,wbb,Lorien,,,2,2,min/maj/ring,Wolves,3,7,,0,0,||,Eric David Anderson
Isles of the Dead that Live,Site,R,Eriadoran Coast,R,fcc,Grey Havens,,,1,2,min/maj/ring,Undead,2,8,,0,0,|Each character wounded must make a corruption check.|,Rob Alexander
Lake-town,Site,CB,Northern Rhovanion,B,wbbw,Lorien,,,2,2,,,0,0,,0,0,||,Eric David Anderson
Lond Galen,Site,CB,Anfalas,B,w,Edhellond,,,1,1,,,0,0,,0,0,||,J. Wallace Jones
Lorien,Site,CB,Wold & Foothills,H,wwbw,Rivendell,wbffbw,Edhellond,2,2,,,0,0,,0,0,||,Stefano Baldo
Lossadan Cairn,Site,CA,Forochel,R,www,Rivendell,,,2,2,min/maj/gr,Undead,2,8,,0,0,|*--Palantiri Only Each character wounded must make a corruption check.|,J. Wallace Jones
Lossadan Camp,Site,CB,Forochel,B,www,Rivendell,,,2,2,,,0,0,,0,0,||,Lori Deitrick
Minas Morgul,Site,R,Imlad Morgul,D,wbfws,Lorien,,,3,4,min/maj/gr,Undead,3,8,,0,0,|Each character wounded must make a corruption check.|,Angus McBride
Minas Tirith,Site,F2,Anorien,F,wbf,Lorien,,,2,2,,,0,0,,0,0,||,Eric David Anderson
Moria,Site,F3,Redhorn Gate,S,ww,Lorien,,,2,3,min/maj/gr/ring,Orcs,4,7,,0,0,||,Kevin Ward
Mount Doom,Site,U,Gorgoroth,S,wbfwsd,Lorien,,,3,6,,,0,0,,0,0,|Any company moving to Mount Doom has its hazard limit modified by +2 and hazard creatures may always be played keyed to the site regardless of any other cards played.|,J. Wallace Jones
Mount Gram,Site,F2,Angmar,S,ws,Rivendell,,,2,3,min/maj,Orcs,3,6,,0,0,||,Susan Van Camp
Mount Gundabad,Site,U,Gundabad,S,wbd,Lorien,,,2,3,min/maj/gr,Orcs,2,8,,0,0,||,Angus McBride
Old Forest,Site,CA,Cardolan,B,ww,Rivendell,,,1,1,,,0,0,,0,0,|Healing Cards affect all characters at the site.|,Kevin Ward
Ost-in-Edhil,Site,U,Hollin,R,ww,Rivendell,,,1,1,min/ring,Wolves,3,5,,0,0,||,Mark Poole
Pelargir,Site,CB,Lebennin,F,wbf,Edhellond,,,2,2,,,0,0,,0,0,||,J. Wallace Jones
Rhosgobel,Site,F2,Southern Mirkwood,F,wbd,Lorien,,,2,3,min,,0,0,,0,0,|Healing Cards affect all characters at the site.|,Tom Dow
Rivendell,Site,CB,Rhudaur,H,wbww,Lorien,fww,Grey Havens,2,2,,,0,0,,0,0,||,Stefano Baldo
Ruined Signal Tower,Site,F2,Enedhwaith,R,www,Rivendell,,,2,2,min/maj,Spiders,2,8,,0,0,||,Mark Poole
Sarn Goriwing,Site,CA,Heart of Mirkwood,S,wbww,Lorien,,,2,2,min/maj,Orcs,3,5,,0,0,||,J. Wallace Jones
Shelob''s Lair,Site,R,Imlad Morgul,S,wbfws,Lorien,,,3,4,min/maj,Orcs,2,8,,0,0,||,Kevin Ward
Shrel-Kain,Site,CB,Dorwinion,B,wbbwb,Lorien,,,3,3,,,0,0,,0,0,||,J. Wallace Jones
Southron Oasis,Site,R,Harondor,B,wfcw,Edhellond,,,2,2,,,0,0,,0,0,||,Tom Dow
Stone-circle,Site,R,Old Pukel Gap,R,ww,Edhellond,,,1,1,info/min,Pukel-man,1,9,,0,0,||,Christina Wald
The Lonely Mountain,Site,F2,Northern Rhovanion,R,wbbw,Lorien,,,2,2,min/maj/gr/ring,Dragon,1,14,,0,0,||,Rob Alexander
The Stones,Site,R,Andrast,R,ww,Edhellond,,,1,1,min/maj/gr,Pukel-men,2,9,,0,0,||,Pat Morrissey
The White Towers,Site,U,Arthedain,R,ww,Rivendell,,,1,1,,Wolves,2,6,,0,0,||,Audrey Corman
The Wind Throne,Site,F5,Grey Mountain Narrows,R,wbs,Lorien,,,2,2,info/min/maj,Orcs,3,7,,0,0,||,Pat Morrissey
Thranduil''s Halls,Site,F1,Woodland Realms,F,wbb,Lorien,,,2,2,,,0,0,,0,0,||,Mark Forrer
Tolfalas,Site,R,Mouths of the Anduin,R,wfc,Edhellond,,,2,2,min/maj/gr,Undead,3,7,,0,0,|Each character wounded must make a corruption check.|,Douglas Chaffee
Vale of Erech,Site,R,Lamedon,B,wb,Edhellond,,,1,1,,,0,0,,0,0,||,J. Wallace Jones
Variag Camp,Site,R,Khand,B,wfcws,Edhellond,,,3,4,,,0,0,,0,0,||,Storn Cook
Weathertop,Site,F4,Arthedain,R,ww,Rivendell,,,1,1,info,Wolves,2,6,,0,0,||,Tom Dow
Wellinghall,Site,F1,Fangorn,F,ww,Lorien,,,1,1,,,0,0,,0,0,||,Angus McBride
Woodmen-town,Site,CB,Western Mirkwood,B,wbw,Lorien,,,2,2,,,0,0,,0,0,||,J. Wallace Jones
Wose Passage-hold,Site,CB,Old Pukel-land,B,www,Edhellond,,,2,2,,,0,0,,0,0,||,J. Wallace Jones'.! !

Object subclass: #MEGWorldFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MEG-Tests-Factories'!

!MEGWorldFactory methodsFor: 'public' stamp: 'SergioFedi 6/6/2016 16:44'!
newWorld
	| world gandalf sites characters wizard |
	world := MEGWorld new.
	sites := MEGSiteFactory new newSites.
	gandalf := MEGCharacter named: 'Gandalf' homeSiteType: 'Haven'.
	characters := MEGCharacterFactory new newCharacters.
	wizard := MEGAgent named: 'Jugador 1'.
	world addSites: sites.
	world addCharacter: gandalf.
	world addCharacters: characters.
	world addAgent: wizard.
	^ world! !
